@@ -11,7 +11,8 @@ or subclasses built-in ElementTree classes to add features that are
 only availble in lxml, like OrderedDict for attributes, pretty_print and
 iterwalk.
 """
-from fontTools.misc.py23 import basestring, unicode, tounicode, open
+
+from fontTools.misc.textTools import tostr
 
 
 XML_DECLARATION = """<?xml version='1.0' encoding='%s'?>"""
@@ -150,9 +151,7 @@ except ImportError:
                 )
                 return
 
-            if encoding is unicode or (
-                encoding is not None and encoding.lower() == "unicode"
-            ):
+            if encoding is not None and encoding.lower() == "unicode":
                 if xml_declaration:
                     raise ValueError(
                         "Serialisation to unicode must not request an XML declaration"
@@ -242,11 +241,12 @@ except ImportError:
         Reject all bytes input that contains non-ASCII characters.
         """
         try:
-            s = tounicode(s, encoding="ascii", errors="strict")
+            s = tostr(s, encoding="ascii", errors="strict")
         except UnicodeDecodeError:
             raise ValueError(
                 "Bytes strings can only contain ASCII characters. "
-                "Use unicode strings for non-ASCII characters.")
+                "Use unicode strings for non-ASCII characters."
+            )
         except AttributeError:
             _raise_serialization_error(s)
         if s and _invalid_xml_string.search(s):
@@ -356,7 +356,7 @@ except ImportError:
             if isinstance(tag, QName):
                 if tag.text not in qnames:
                     add_qname(tag.text)
-            elif isinstance(tag, basestring):
+            elif isinstance(tag, str):
                 if tag not in qnames:
                     add_qname(tag)
             elif tag is not None and tag is not Comment and tag is not PI:
@@ -427,9 +427,7 @@ except ImportError:
             write(_escape_cdata(elem.tail))
 
     def _raise_serialization_error(text):
-        raise TypeError(
-            "cannot serialize %r (type %s)" % (text, type(text).__name__)
-        )
+        raise TypeError("cannot serialize %r (type %s)" % (text, type(text).__name__))
 
     def _escape_cdata(text):
         # escape character data
