@@ -3,6 +3,7 @@ https://docs.microsoft.com/en-us/typography/opentype/spec/chapter2#featurevariat
 
 NOTE: The API is experimental and subject to change.
 """
+
 from fontTools.misc.dictTools import hashdict
 from fontTools.misc.intTools import bit_count
 from fontTools.ttLib import newTable
@@ -414,6 +415,10 @@ def addFeatureVariationsRaw(font, table, conditionalSubstitutions, featureTag="r
         axis.axisTag: axisIndex for axisIndex, axis in enumerate(font["fvar"].axes)
     }
 
+    hasFeatureVariations = (
+        hasattr(table, "FeatureVariations") and table.FeatureVariations is not None
+    )
+
     featureVariationRecords = []
     for conditionSet, lookupIndices in conditionalSubstitutions:
         conditionTable = []
@@ -440,11 +445,19 @@ def addFeatureVariationsRaw(font, table, conditionalSubstitutions, featureTag="r
                     varFeatureIndex, combinedLookupIndices
                 )
             )
-        featureVariationRecords.append(
-            buildFeatureVariationRecord(conditionTable, records)
-        )
+        if hasFeatureVariations and (
+            fvr := findFeatureVariationRecord(table.FeatureVariations, conditionTable)
+        ):
+            fvr.FeatureTableSubstitution.SubstitutionRecord.extend(records)
+            fvr.FeatureTableSubstitution.SubstitutionCount = len(
+                fvr.FeatureTableSubstitution.SubstitutionRecord
+            )
+        else:
+            featureVariationRecords.append(
+                buildFeatureVariationRecord(conditionTable, records)
+            )
 
-    if hasattr(table, "FeatureVariations") and table.FeatureVariations is not None:
+    if hasFeatureVariations:
         if table.FeatureVariations.Version != 0x00010000:
             raise VarLibError(
                 "Unsupported FeatureVariations table version: "
@@ -614,6 +627,21 @@ def buildConditionTable(axisIndex, filterRangeMinValue, filterRangeMaxValue):
     return ct
 
 
+def findFeatureVariationRecord(featureVariations, conditionTable):
+    """Find a FeatureVariationRecord that has the same conditionTable."""
+    if featureVariations.Version != 0x00010000:
+        raise VarLibError(
+            "Unsupported FeatureVariations table version: "
+            f"0x{featureVariations.Version:08x} (expected 0x00010000)."
+        )
+
+    for fvr in featureVariations.FeatureVariationRecord:
+        if conditionTable == fvr.ConditionSet.ConditionTable:
+            return fvr
+
+    return None
+
+
 def sortFeatureList(table):
     """Sort the feature list by feature tag, and remap the feature indices
     elsewhere. This is needed after the feature list has been modified.
