@@ -87,9 +87,22 @@ class T2CharStringTest(unittest.TestCase):
             (1.0, "1e 1f"),  # 1
             (-1.0, "1e e1 ff"),  # -1
             (98765.37e2, "1e 98 76 53 7f"),  # 9876537
-            (1234567890.0, "1e 1a 23 45 67 9b 09 ff"),  # 1234567890
-            (9.876537e-4, "1e a0 00 98 76 53 7f"),  # 9.876537e-24
-            (9.876537e4, "1e 98 76 5a 37 ff"),  # 9.876537e+24
+            (1234567890.0, "1e 12 34 56 79 b2 ff"),  # 12345679E2
+            (9.876537e-4, "1e 98 76 53 7c 10 ff"),  # 9876537E-10
+            (9.876537e4, "1e 98 76 5a 37 ff"),  # 98765.37
+            (1000.0, "1e 1b 3f"),  # 1E3
+            (-1000.0, "1e e1 b3 ff"),  # -1E3
+            (1e8, "1e 1b 8f"),  # 1E8
+            (1e-5, "1e 1c 5f"),  # 1E-5
+            (1.2e8, "1e 12 b7 ff"),  # 12E7
+            (1.2345e-5, "1e 12 34 5c 9f"),  # 12345E-9
+            (9.0987654e8, "1e 90 98 76 54 0f"),  # 909876540
+            (0.1, "1e a1 ff"),  # .1
+            (-0.1, "1e ea 1f"),  # -.1
+            (0.01, "1e 1c 2f"),  # 1e-2
+            (-0.01, "1e e1 c2 ff"),  # -1e-2
+            (0.0123, "1e 12 3c 4f"),  # 123e-4
+            (-0.0123, "1e e1 23 c4 ff"),  # -123e-4
         ]
 
         for sample in testNums:
