@@ -1,5 +1,6 @@
 from fontTools.ttLib import TTFont
 from fontTools.ttLib import ttGlyphSet
+from fontTools.ttLib.ttGlyphSet import LerpGlyphSet
 from fontTools.pens.recordingPen import (
     RecordingPen,
     RecordingPointPen,
@@ -164,6 +165,53 @@ class TTGlyphSetTest(object):
 
         assert actual == expected, (location, actual, expected)
 
+    @pytest.mark.parametrize(
+        "fontfile, locations, factor, expected",
+        [
+            (
+                "I.ttf",
+                ({"wght": 400}, {"wght": 1000}),
+                0.5,
+                [
+                    ("moveTo", ((151.5, 0.0),)),
+                    ("lineTo", ((458.5, 0.0),)),
+                    ("lineTo", ((458.5, 1456.0),)),
+                    ("lineTo", ((151.5, 1456.0),)),
+                    ("closePath", ()),
+                ],
+            ),
+            (
+                "I.ttf",
+                ({"wght": 400}, {"wght": 1000}),
+                0.25,
+                [
+                    ("moveTo", ((163.25, 0.0),)),
+                    ("lineTo", ((412.75, 0.0),)),
+                    ("lineTo", ((412.75, 1456.0),)),
+                    ("lineTo", ((163.25, 1456.0),)),
+                    ("closePath", ()),
+                ],
+            ),
+        ],
+    )
+    def test_lerp_glyphset(self, fontfile, locations, factor, expected):
+        font = TTFont(self.getpath(fontfile))
+        glyphset1 = font.getGlyphSet(location=locations[0])
+        glyphset2 = font.getGlyphSet(location=locations[1])
+        glyphset = LerpGlyphSet(glyphset1, glyphset2, factor)
+
+        assert "I" in glyphset
+
+        pen = RecordingPen()
+        glyph = glyphset["I"]
+
+        assert glyphset.get("foobar") is None
+
+        glyph.draw(pen)
+        actual = pen.value
+
+        assert actual == expected, (locations, actual, expected)
+
     def test_glyphset_varComposite_components(self):
         font = TTFont(self.getpath("varc-ac00-ac01.ttf"))
         glyphset = font.getGlyphSet()
@@ -179,33 +227,57 @@ class TTGlyphSetTest(object):
                 "addVarComponent",
                 (
                     "glyph00003",
-                    DecomposedTransform(460.0, 676.0, 0, 1, 1, 0, 0, 0, 0),
-                    {
-                        "0000": 0.84661865234375,
-                        "0001": 0.98944091796875,
-                        "0002": 0.47283935546875,
-                        "0003": 0.446533203125,
-                    },
+                    DecomposedTransform(
+                        translateX=0,
+                        translateY=0,
+                        rotation=0,
+                        scaleX=1,
+                        scaleY=1,
+                        skewX=0,
+                        skewY=0,
+                        tCenterX=0,
+                        tCenterY=0,
+                    ),
+                    {},
                 ),
             ),
             (
                 "addVarComponent",
                 (
-                    "glyph00004",
-                    DecomposedTransform(932.0, 382.0, 0, 1, 1, 0, 0, 0, 0),
-                    {
-                        "0000": 0.93359375,
-                        "0001": 0.916015625,
-                        "0002": 0.523193359375,
-                        "0003": 0.32806396484375,
-                        "0004": 0.85089111328125,
-                    },
+                    "glyph00005",
+                    DecomposedTransform(
+                        translateX=0,
+                        translateY=0,
+                        rotation=0,
+                        scaleX=1,
+                        scaleY=1,
+                        skewX=0,
+                        skewY=0,
+                        tCenterX=0,
+                        tCenterY=0,
+                    ),
+                    {},
                 ),
             ),
         ]
 
         assert actual == expected, (actual, expected)
 
+    def test_glyphset_varComposite_conditional(self):
+        font = TTFont(self.getpath("varc-ac01-conditional.ttf"))
+
+        glyphset = font.getGlyphSet()
+        pen = RecordingPen()
+        glyph = glyphset["uniAC01"]
+        glyph.draw(pen)
+        assert len(pen.value) == 2
+
+        glyphset = font.getGlyphSet(location={"wght": 800})
+        pen = RecordingPen()
+        glyph = glyphset["uniAC01"]
+        glyph.draw(pen)
+        assert len(pen.value) == 3
+
     def test_glyphset_varComposite1(self):
         font = TTFont(self.getpath("varc-ac00-ac01.ttf"))
         glyphset = font.getGlyphSet(location={"wght": 600})
@@ -217,77 +289,24 @@ class TTGlyphSetTest(object):
         actual = pen.value
 
         expected = [
-            ("moveTo", ((432, 678),)),
-            ("lineTo", ((432, 620),)),
-            (
-                "qCurveTo",
-                (
-                    (419, 620),
-                    (374, 621),
-                    (324, 619),
-                    (275, 618),
-                    (237, 617),
-                    (228, 616),
-                ),
-            ),
-            ("qCurveTo", ((218, 616), (188, 612), (160, 605), (149, 601))),
-            ("qCurveTo", ((127, 611), (83, 639), (67, 654))),
-            ("qCurveTo", ((64, 657), (63, 662), (64, 666))),
-            ("lineTo", ((72, 678),)),
-            ("qCurveTo", ((93, 674), (144, 672), (164, 672))),
-            (
-                "qCurveTo",
-                (
-                    (173, 672),
-                    (213, 672),
-                    (266, 673),
-                    (323, 674),
-                    (377, 675),
-                    (421, 678),
-                    (432, 678),
-                ),
-            ),
+            ("moveTo", ((82, 108),)),
+            ("qCurveTo", ((188, 138), (350, 240), (461, 384), (518, 567), (518, 678))),
+            ("lineTo", ((518, 732),)),
+            ("lineTo", ((74, 732),)),
+            ("lineTo", ((74, 630),)),
+            ("lineTo", ((456, 630),)),
+            ("lineTo", ((403, 660),)),
+            ("qCurveTo", ((403, 575), (358, 431), (267, 314), (128, 225), (34, 194))),
             ("closePath", ()),
-            ("moveTo", ((525, 619),)),
-            ("lineTo", ((412, 620),)),
-            ("lineTo", ((429, 678),)),
-            ("lineTo", ((466, 697),)),
-            ("qCurveTo", ((470, 698), (482, 698), (486, 697))),
-            ("qCurveTo", ((494, 693), (515, 682), (536, 670), (541, 667))),
-            ("qCurveTo", ((545, 663), (545, 656), (543, 652))),
-            ("lineTo", ((525, 619),)),
+            ("moveTo", ((702, 385),)),
+            ("lineTo", ((897, 385),)),
+            ("lineTo", ((897, 485),)),
+            ("lineTo", ((702, 485),)),
             ("closePath", ()),
-            ("moveTo", ((63, 118),)),
-            ("lineTo", ((47, 135),)),
-            ("qCurveTo", ((42, 141), (48, 146))),
-            ("qCurveTo", ((135, 213), (278, 373), (383, 541), (412, 620))),
-            ("lineTo", ((471, 642),)),
-            ("lineTo", ((525, 619),)),
-            ("qCurveTo", ((496, 529), (365, 342), (183, 179), (75, 121))),
-            ("qCurveTo", ((72, 119), (65, 118), (63, 118))),
-            ("closePath", ()),
-            ("moveTo", ((925, 372),)),
-            ("lineTo", ((739, 368),)),
-            ("lineTo", ((739, 427),)),
-            ("lineTo", ((822, 430),)),
-            ("lineTo", ((854, 451),)),
-            ("qCurveTo", ((878, 453), (930, 449), (944, 445))),
-            ("qCurveTo", ((961, 441), (962, 426))),
-            ("qCurveTo", ((964, 411), (956, 386), (951, 381))),
-            ("qCurveTo", ((947, 376), (931, 372), (925, 372))),
-            ("closePath", ()),
-            ("moveTo", ((729, -113),)),
-            ("lineTo", ((674, -113),)),
-            ("qCurveTo", ((671, -98), (669, -42), (666, 22), (665, 83), (665, 102))),
-            ("lineTo", ((665, 763),)),
-            ("qCurveTo", ((654, 780), (608, 810), (582, 820))),
-            ("lineTo", ((593, 850),)),
-            ("qCurveTo", ((594, 852), (599, 856), (607, 856))),
-            ("qCurveTo", ((628, 855), (684, 846), (736, 834), (752, 827))),
-            ("qCurveTo", ((766, 818), (766, 802))),
-            ("lineTo", ((762, 745),)),
-            ("lineTo", ((762, 134),)),
-            ("qCurveTo", ((762, 107), (757, 43), (749, -25), (737, -87), (729, -113))),
+            ("moveTo", ((641, -92),)),
+            ("lineTo", ((752, -92),)),
+            ("lineTo", ((752, 813),)),
+            ("lineTo", ((641, 813),)),
             ("closePath", ()),
         ]
 
@@ -482,7 +501,7 @@ class TTGlyphSetTest(object):
                 "qCurveTo",
                 (
                     (919, 41),
-                    (854, 67),
+                    (854, 68),
                     (790, 98),
                     (729, 134),
                     (671, 173),
@@ -494,7 +513,7 @@ class TTGlyphSetTest(object):
             ("lineTo", ((522, 286),)),
             ("qCurveTo", ((511, 267), (498, 235), (493, 213), (492, 206))),
             ("lineTo", ((515, 209),)),
-            ("qCurveTo", ((569, 146), (695, 44), (835, -32), (913, -57))),
+            ("qCurveTo", ((569, 146), (695, 45), (835, -32), (913, -57))),
             ("closePath", ()),
             ("moveTo", ((474, 274),)),
             ("lineTo", ((452, 284),)),
